@@ -10,6 +10,7 @@ class CloneManga(BasicComicModule, BounceMixin):
 
     submodules = {
         'AprilAndMay': 'http://manga.clone-army.org/anm.php',
+        'Kanami': 'http://manga.clone-army.org/kanami.php',
         'NanasEverydayLife': 'http://manga.clone-army.org/nana.php',
         'PaperEleven': 'http://manga.clone-army.org/pxi.php',
         'Tomoyo42sRoom': 'http://manga.clone-army.org/t42r.php',
@@ -18,7 +19,7 @@ class CloneManga(BasicComicModule, BounceMixin):
     def __init__(self, submodule):
         BasicComicModule.__init__(self)
         self.baseUrl = self.submodules[submodule]
-        self.imageUrl = self.latestUrl + '?page=%s'
+        self.imageUrl = self.baseUrl + '?page=%s'
         self.name = 'CloneManga' + '/' + submodule
 
     def getFilename(self, imageUrl, pageUrl):
