@@ -1,8 +1,6 @@
 import re
-import urllib
-import cgi
-from dosage.util import urlopen
 from dosage.modules.helpers.BasicComicModule import BasicComicModule
+from dosage.util import urlopen, getQueryParams
 
 class InkTank(BasicComicModule):
     imageUrl = 'd/%s.html'
@@ -33,6 +31,4 @@ class InkTank(BasicComicModule):
             if match:
                 return match.group(1)
             
-        queryString = urllib.splitquery(pageUrl)[1]
-        attribs = cgi.parse_qs(queryString)
-        return attribs['nav'][0]
+        return getQueryParams(pageUrl)['nav'][0]
