@@ -98,3 +98,6 @@ class KingFeatures:
             comics = self.getNextComics()
             if comics:
                 yield comics
+
+    def getHelp(self):
+        return self.help
