@@ -2,7 +2,7 @@ import re
 from dosage.modules.helpers.BasicComicModule import BasicComicModule
 
 class SnafuComics(BasicComicModule):
-    imageUrl = 'index.php?strip_id=11'
+    imageUrl = 'index.php?strip_id=%s'
     imageSearch = re.compile(r'<center><img src="(comics/\d{6}\..+?)" width="\d+" height="\d+"></center>')
     prevSearch = re.compile(r'<a href="(\?strip_id=\d+)" onmouseover="window\.status=\'Previous\'')
     help = 'Index format: n (unpadded)'
